pilas.interpolaciones.Interpolacion

Package pilas :: Module interpolaciones :: Class Interpolacion |
[hide private]
[frames] | no frames]

# Class Interpolacion

source code

    object --+
             |
            Interpolacion

Known Subclasses:
  - AceleracionGradual
  - , DesaceleracionGradual
  - , ElasticoFinal
  - , ElasticoInicial
  - , Lineal
  - , ReboteFinal
  - , ReboteInicial

    Representa una interpolacion, que pasa por varios puntos clave.

    Las interpolacione se utilizan para realizar movimientos de
    actores en la pantalla. O simplemente para cambiar el
    estado de un actor de un punto a otro, por ejemplo, de 0 a 360
    grados de manera gradual.

    Todo objeto de interpolaciones se puede asignar directamente a
    una propiedad de un actor. Por ejemplo:

        actor.rotation = pilas.interpolations.Lineal(400)

    note que hay un atajo para usar estos objetos, es mejor
    utilizar directamente una sentencias como la que sigue::

        actor.rotation = pilas.interpolate(360)

Instance Methods | [hide private]
__init__(self, values, duration, delay) Inicializa la interpolación. | source code
apply(self, target, function, type) Aplica la interpolación a un actor usando un método. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, values, duration, delay) (Constructor) | source code
Inicializa la interpolación. ``values`` tiene que ser una lista con todos los puntos por los que se quiere adoptar valores y ``duration`` es la cantidad de segundos que deben tomarse para realizar la interpolación. Overrides: object.__init__

### apply(self, target, function, type) | source code
Aplica la interpolación a un actor usando un método. Esta funcionalidad se utiliza para que toda interpolación se pueda acoplar a un actor. La idea es contar con la interpolación, un actor y luego ponerla en funcionamiento:
       mi_interpolacion.apply(mono, set_rotation)
de esta forma los dos objetos están y seguirán estando desacoplados.